summaryrefslogtreecommitdiff
path: root/nuttx/net/tcp/tcp_send_unbuffered.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/net/tcp/tcp_send_unbuffered.c')
-rw-r--r--nuttx/net/tcp/tcp_send_unbuffered.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/net/tcp/tcp_send_unbuffered.c b/nuttx/net/tcp/tcp_send_unbuffered.c
index 2b2a6e16f..193db3f34 100644
--- a/nuttx/net/tcp/tcp_send_unbuffered.c
+++ b/nuttx/net/tcp/tcp_send_unbuffered.c
@@ -297,12 +297,12 @@ static uint16_t tcpsend_interrupt(FAR struct net_driver_s *dev,
if (sndlen >= CONFIG_NET_TCP_SPLIT_SIZE)
{
/* sndlen is the number of bytes remaining to be sent.
* uip_mss(conn) will return the number of bytes that can sent
* in one packet. The difference, then, is the number of bytes
* that would be sent in the next packet after this one.
*/
- int32_t next_sndlen = sndlen - uip_mss(conn);
+ int32_t next_sndlen = sndlen - tcp_mss(conn);
/* Is this the even packet in the packet pair transaction? */
@@ -329,13 +329,13 @@ static uint16_t tcpsend_interrupt(FAR struct net_driver_s *dev,
{
/* Will there be another (even) packet afer this one?
* (next_sndlen > 0) Will the split condition occur on that
* next, even packet? ((next_sndlen - uip_mss(conn)) < 0) If
* so, then perform the split now to avoid the case where the
* byte count is less than CONFIG_NET_TCP_SPLIT_SIZE on the
* next pair.
*/
- if (next_sndlen > 0 && (next_sndlen - uip_mss(conn)) < 0)
+ if (next_sndlen > 0 && (next_sndlen - tcp_mss(conn)) < 0)
{
/* Here, we know that sndlen must be MSS < sndlen <= 2*MSS
* and so (sndlen / 2) is <= MSS.
@@ -352,9 +352,9 @@ static uint16_t tcpsend_interrupt(FAR struct net_driver_s *dev,
#endif /* CONFIG_NET_TCP_SPLIT */
- if (sndlen > uip_mss(conn))
+ if (sndlen > tcp_mss(conn))
{
- sndlen = uip_mss(conn);
+ sndlen = tcp_mss(conn);
}
/* Check if we have "space" in the window */
@@ -297,12 +297,12 @@ static uint16_t tcpsend_interrupt(FAR struct net_driver_s *dev,
{
/* sndlen is the number of bytes remaining to be sent.
- * uip_mss(conn) will return the number of bytes that can sent
+ * tcp_mss(conn) will return the number of bytes that can sent
* in one packet. The difference, then, is the number of bytes
* that would be sent in the next packet after this one.
@@ -329,13 +329,13 @@ static uint16_t tcpsend_interrupt(FAR struct net_driver_s *dev,
/* Will there be another (even) packet afer this one?
* (next_sndlen > 0) Will the split condition occur on that
- * next, even packet? ((next_sndlen - uip_mss(conn)) < 0) If
+ * next, even packet? ((next_sndlen - tcp_mss(conn)) < 0) If
* so, then perform the split now to avoid the case where the
* byte count is less than CONFIG_NET_TCP_SPLIT_SIZE on the